
/*
 * libcookie - a HTTP cookie library for ANSI C
 * Copyright (C) 1998-1999 Alex Demko <ademko@mbnet.mb.ca>
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 * cookie.h - header file for libcookie
 * $Id: cookie.h,v 1.8 1999/03/06 17:19:46 ademko Exp $
 *
 */

/* see MANUAL for better function documentation */

#ifndef _INCLUDED_LIB_COOKIE
#define _INCLUDED_LIB_COOKIE

#include <stdio.h>

/* The maximum length of the string buffers used in
   the library. Increase and recompile if need be. */

#define COOKIE_STRING_LENGTH 300

/* cookie get buffer loading routines */
int cookieLoad(void);
char * cookieGet(const char *cookiename);
void cookieFree(void);

/* cookie interation routines - must be used between cookieLoad()
   and cookieFree() calls */
void * cookieListOpen(void);
char * cookieListName(void *handle);
char * cookieListValue(void *handle);
void * cookieListNext(void *handle);

/* cookieSet() sets a cookie. This should be called after you've
   started your header (ie. you sent 'Content-type: text/html')
   but before you sent a blank (which indicates the end of the
   http header) */
void cookieSet(const char *name, const char *value);

/* sets various parameters */
char * cookieSetExpires(const char *newdate);
char * cookieSetDomain(const char *newdomain);
char * cookieSetPath(const char *newpath);

/* Sets or reads the secure flag. If set, cookies will only
   be sent over a secure (ie. SSL) connection */
int cookieSetSecure(int needsecure);
int cookieGetSecure(void);

/* Sets the stream that all the routines write to. Initially
   it's 'stdout'. Returns the old stream. No error checking
   is done on the validaty of the new stream. */

FILE * cookieSetOutFile(FILE *newfile);

#endif

